@@ -15,10 +15,9 @@ use YAML::Syck;
 
 extends 'App::VTide::Command::Run';
 
-our $VERSION = version->new('0.1.11');
+our $VERSION = version->new('0.1.12');
 our $NAME    = 'who';
 our $OPTIONS = [
-    'max|m=i',
     'verbose|v+',
 ];
 sub details_sub { return ( $NAME, $OPTIONS )};
@@ -55,14 +54,13 @@ App::VTide::Command::Who - Tells you about the terminal you are in
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Who version 0.1.11
+This documentation refers to App::VTide::Command::Who version 0.1.12
 
 =head1 SYNOPSIS
 
     vtide who [-f|--force]
 
     OPTIONS
-     -m --max[=]int The maximum number of who sessions to show (Default 10)
      -v --verbose   Show more detailed output
         --help      Show this help
         --man       Show the full man page
